==> bigdata-common-0.0.23-sources.jar: cn/com/duiba/bigdata/common/biz/enums/DayRediskeys.java <==
package cn.com.duiba.bigdata.common.biz.enums;

public enum DayRediskeys {
    //单维度统计

    //活动(条件2)
    D101,

    //广告(全局)
    D103,

    //广告（条件1）
    D104,

    //媒体(全局)
    D107,

    //广告（条件2）
    D109,

    //广告(条件4)
    D110,

    //广告二级标签(全局)
    D111,

    //广告位(条件4)
    D112,

    //广告位素材(全局)
    D113,

    //广告位(全局)
    D114,

    //广告位(条件7)
    D115,


    //两个维度统计

    //媒体 + 活动(条件2)
    D201,

    //广告 + 广告发券次数(全局)
    D202,

    //广告 + 广告发券次数（条件1）
    D203,

    //广告 + 媒体(全局)
    D204,

    //广告 + 媒体(条件1)
    D205,

    //广告 + 广告位(全局)
    D206,

    //广告 + 广告位(条件1)
    D207,

    //广告 + 活动(全局)
    D208,

    //广告 + 活动(条件1)
    D209,

    //广告 + 素材(全局)
    D210,

    //广告 + 广告配置(全局)
    D212,

    //广告 + 广告配置(条件1)
    D213,

    //广告 + 广告位(条件5)
    D221,

    //广告 + 广告配置(条件4)
    D222,

    //广告 + 广告配置(条件5)
    D223,

    //媒体 + 广告二级标签(全局)
    D224,

    //媒体 + 广告位素材(全局)
    D225,

    ///广告 + 广告配置(条件7)
    D226,

    //广告位 + 出价区间(全局)
    D227,

    //广告 + 算法推荐类型(全局)
    D228,

    //广告和媒体行业
    D229,

    //媒体和广告行业
    D230,

    //广告行业和媒体行业
    D231,
    // D233_tag+advert
    D233,
    //三个维度统计

    //媒体 + 广告位 + 活动(条件3)
    D301,

    //广告 + 媒体 + 广告位(全局)
    D302,

    //广告 + 媒体 + 广告发券次数(全局)
    D303,

    //广告 + 媒体 + 广告发券次数(条件1)
    D304,

    //广告 + 媒体 + 素材(全局)
    D305,

    //广告 + 广告配置 + 媒体(全局)
    D311,

    //广告 + 广告配置 + 媒体(条件1)
    D312,

    //广告 + 广告配置 + 流量来源(全局)
    D313,

    //广告 + 广告配置 + 流量来源(条件1)
    D314,

    //广告 + 广告发券次数 + 素材(条件1)
    D315,

    //媒体 + 广告位 + 广告位素材(全局)
    D316,

    //广告 + 广告配置 + 广告位(条件4)
    D323,

    //广告 + 广告配置 + 广告位(全局)
    D324,

    //广告 + 广告配置 + 广告位(条件7)
    D325,

    //广告 + 广告配置 + 出价区间(全局)
    D326,

    //广告 + 媒体 + 算法推荐类型(全局)
    D327,

    //广告 + 广告配置 + 区间
    D328,
    //广告 + tag + app
    D329,
    //四个维度统计

    //广告 + 媒体 + 广告位 + 活动(条件2)
    D401,

    //广告 + 媒体 + 广告发券次数 + 素材(条件1)
    D402,

    //广告 + 广告配置 + 广告位 + 出价区间(全局)
    D403,

    //广告 + 媒体 + 广告位 + 算法推荐类型(全局)
    D404,

    //媒体 + 广告位 + 活动 + 表单广告(场景3)
    D405,

    //广告 +广告配置 + 媒体  + 区间
    D406,
    //五个维度组合

    //广告 + 广告配置 + 广告位 + 广告计费方式 + 托管广告转化成本（条件5）
    D502,

    //appid_slotid_activityid_orientationid_advertid 最细维度
    D503,
    //D504_tag_advert_pkg_covCost_change_type
    D504,
    //appId, slotId, activityId, orientationId, advertId, advertTag
    D601,
    //tag_advert_pkg_covCost_change_type_app
    D602,
    //广告+配置 广告托管数据 天粒度数据按小时存储
    S201,

    //广告+配置+媒体 广告托管数据 天粒度数据按小时存储
    S301,

    //广告+配置+广告位 广告托管数据 天粒度数据按小时存储
    S302,

    //广告+配置+目标转化类型 广告托管数据 天粒度数据按小时存储
    S303;


    public String getPrefix() {
        return super.toString();
    }

    @Override
    public String toString() {
        return super.toString() + "_";
    }
}

==> bigdata-common-0.0.37-sources.jar: cn/com/duiba/bigdata/common/biz/enums/DayRediskeys.java <==
package cn.com.duiba.bigdata.common.biz.enums;

public enum DayRediskeys {
    //单维度统计

    //活动(条件2)
    D101,

    //广告(全局)
    D103,

    //广告（条件1）
    D104,

    //媒体(全局)
    D107,

    //广告（条件2）
    D109,

    //广告(条件4)
    D110,

    //广告二级标签(全局)
    D111,

    //广告位(条件4)
    D112,

    //广告位素材(全局)
    D113,

    //广告位(全局)
    D114,

    //广告位(条件7)
    D115,


    //两个维度统计

    //媒体 + 活动(条件2)
    D201,

    //广告 + 广告发券次数(全局)
    D202,

    //广告 + 广告发券次数（条件1）
    D203,

    //广告 + 媒体(全局)
    D204,

    //广告 + 媒体(条件1)
    D205,

    //广告 + 广告位(全局)
    D206,

    //广告 + 广告位(条件1)
    D207,

    //广告 + 活动(全局)
    D208,

    //广告 + 活动(条件1)
    D209,

    //广告 + 素材(全局)
    D210,

    //广告 + 广告配置(全局)
    D212,

    //广告 + 广告配置(条件1)
    D213,

    //广告 + 广告位(条件5)
    D221,

    //广告 + 广告配置(条件4)
    D222,

    //广告 + 广告配置(条件5)
    D223,

    //媒体 + 广告二级标签(全局)
    D224,

    //媒体 + 广告位素材(全局)
    D225,

    ///广告 + 广告配置(条件7)
    D226,

    //广告位 + 出价区间(全局)
    D227,

    //广告 + 算法推荐类型(全局)
    D228,

    //广告和媒体行业
    D229,

    //媒体和广告行业
    D230,

    //广告行业和媒体行业
    D231,

    // D233_tag+advert
    D233,



    //三个维度统计

    //媒体 + 广告位 + 活动(条件3)
    D301,

    //广告 + 媒体 + 广告位(全局)
    D302,

    //广告 + 媒体 + 广告发券次数(全局)
    D303,

    //广告 + 媒体 + 广告发券次数(条件1)
    D304,

    //广告 + 媒体 + 素材(全局)
    D305,

    //广告 + 广告配置 + 媒体(全局)
    D311,

    //广告 + 广告配置 + 媒体(条件1)
    D312,

    //广告 + 广告配置 + 流量来源(全局)
    D313,

    //广告 + 广告配置 + 流量来源(条件1)
    D314,

    //广告 + 广告发券次数 + 素材(条件1)
    D315,

    //媒体 + 广告位 + 广告位素材(全局)
    D316,

    //广告 + 广告配置 + 广告位(条件4)
    D323,

    //广告 + 广告配置 + 广告位(全局)
    D324,

    //广告 + 广告配置 + 广告位(条件7)
    D325,

    //广告 + 广告配置 + 出价区间(全局)
    D326,

    //广告 + 媒体 + 算法推荐类型(全局)
    D327,

    //广告 + 广告配置 + 区间
    D328,

    //广告 + tag + app
    D329,




    //四个维度统计

    //广告 + 媒体 + 广告位 + 活动(条件2)
    D401,

    //广告 + 媒体 + 广告发券次数 + 素材(条件1)
    D402,

    //广告 + 广告配置 + 广告位 + 出价区间(全局)
    D403,

    //广告 + 媒体 + 广告位 + 算法推荐类型(全局)
    D404,

    //媒体 + 广告位 + 活动 + 表单广告(场景3)
    D405,

    //广告 +广告配置 + 媒体  + 区间
    D406,

    //媒体 + 广告位 + 广告位素材 + 素材推荐算法版本
    D407,

    //(普通活动)广告位  资源位类型  插件id  插件次序
    D408,

    //(插件)广告位  资源位类型  插件id  插件次序
    D409,

    //媒体 + 广告位 + 活动 + 活动推荐算法版本(条件3)
    D410,


    //五个维度组合

    //广告 + 广告配置 + 广告位 + 广告计费方式 + 托管广告转化成本（条件5）
    D502,

    //appid_slotid_activityid_orientationid_advertid 最细维度
    D503,
    //D504_tag_advert_pkg_covCost_change_type
    D504,
    //appId, slotId, activityId, orientationId, advertId, advertTag
    D601,
    //tag_advert_pkg_covCost_change_type_app
    D602,
    //广告+配置 广告托管数据 天粒度数据按小时存储
    S201,

    //广告+配置+媒体 广告托管数据 天粒度数据按小时存储
    S301,

    //广告+配置+广告位 广告托管数据 天粒度数据按小时存储
    S302,

    //广告+配置+目标转化类型 广告托管数据 天粒度数据按小时存储
    S303;


    public String getPrefix() {
        return super.toString();
    }

    @Override
    public String toString() {
        return super.toString() + "_";
    }
}
